@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# (c) Copyright 2003-2007 Hewlett-Packard Development Company, L.P.
+# (c) Copyright 2003-2015 HP Development Company, L.P.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -304,11 +304,25 @@ def get_pyQt4_version():
         ver = QtCore.PYQT_VERSION_STR
     return ver
 
+
+def get_pyQt5_version():
+    log.debug("Checking PyQt 5.x version...")
+    ver ='-'
+    # PyQt 5
+    try:
+        import PyQt5
+    except ImportError:
+        ver='-'
+    else:
+        from PyQt5 import QtCore
+        ver = QtCore.PYQT_VERSION_STR
+    return ver
+
 def get_reportlab_version():
     try:
         log.debug("Trying to import 'reportlab'...")
         import reportlab
-        ver = reportlab.Version
+        ver = str(reportlab.Version)
     except ImportError:
         return '-'
     else:
@@ -352,11 +366,13 @@ def get_xsane_version():
 
 def get_pil_version():
     try:
-        from PIL import Image
+       # from PIL import Image
+       import PIL
     except ImportError:
         return '-'
     else:
-         return Image.VERSION
+         #return Image.PILLOW_VERSION
+         return PIL.__version__
 
 def get_libpthread_version():
     try:
