@@ -1,7 +1,7 @@
 /*****************************************************************************\
   HPCupsFilter.cpp : Interface for HPCupsFilter class
 
-  Copyright (c) 1996 - 2009, Hewlett-Packard Co.
+  Copyright (c) 1996 - 2015, HP Co.
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -12,7 +12,7 @@
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
-  3. Neither the name of Hewlett-Packard nor the names of its
+  3. Neither the name of HP nor the names of its
      contributors may be used to endorse or promote products derived
      from this software without specific prior written permission.
 
@@ -31,6 +31,11 @@
 \*****************************************************************************/
 
 #include "HPCupsFilter.h"
+
+#ifndef DISABLE_IMAGEPROCESSOR
+#include "ImageProcessor.h"
+#endif
+
 #include <signal.h>
 #include <sys/wait.h>
 #include <sys/utsname.h>
@@ -281,6 +286,7 @@ DRIVER_ERROR HPCupsFilter::startPage (cups_page_header2_t *cups_header)
     }
 
     m_JA.quality_attributes.media_type = cups_header->cupsMediaType;
+    m_JA.quality_attributes.media_subtype = cups_header->cupsInteger[6];
     m_JA.quality_attributes.print_quality = atoi(cups_header->OutputType);
     m_JA.quality_attributes.horizontal_resolution = cups_header->HWResolution[0];
     m_JA.quality_attributes.vertical_resolution   = cups_header->HWResolution[1];
@@ -332,7 +338,16 @@ DRIVER_ERROR HPCupsFilter::startPage (cups_page_header2_t *cups_header)
 
     int    horz_res = cups_header->HWResolution[0];
     int    vert_res = cups_header->HWResolution[1];
-    m_JA.media_attributes.pcl_id = cups_header->cupsInteger[0];
+    //  Custom Page size should have cupsInteger0 set as 101 instead of 0
+    if(strncmp(cups_header->cupsPageSizeName, "Custom",6) == 0)
+    {
+	m_JA.media_attributes.pcl_id = 101;    
+    }
+    else
+    {
+        m_JA.media_attributes.pcl_id = cups_header->cupsInteger[0];
+    }	    
+
     m_JA.media_attributes.printable_start_x = (cups_header->Margins[0] * horz_res) / 72;
     m_JA.media_attributes.printable_start_y = ((cups_header->PageSize[1] - cups_header->ImagingBoundingBox[3]) * vert_res) / 72;
     m_JA.media_attributes.horizontal_overspray = (xoverspray * horz_res) / 1000;
@@ -350,6 +365,16 @@ DRIVER_ERROR HPCupsFilter::startPage (cups_page_header2_t *cups_header)
         m_JA.mech_offset = atoi(attr->value);
     }
 
+    if(cups_header->PageSize[0] > 612) // Check for B size paper. B Size paper has width > 8.5 inch (612 points)
+    {
+        //Check if HPMechOffsetBSize attribute is defined. If it is defined then use this offset value.
+        if (((attr = ppdFindAttr(m_ppd, "HPMechOffsetBSize", NULL)) != NULL) && (attr && attr->value != NULL)) 
+        {
+            m_JA.mech_offset = atoi(attr->value);
+        }
+
+    }
+
 //  Get printer platform name
     if (((attr = ppdFindAttr(m_ppd, "hpPrinterPlatform", NULL)) != NULL) && (attr->value != NULL)) {
 
@@ -375,6 +400,16 @@ DRIVER_ERROR HPCupsFilter::startPage (cups_page_header2_t *cups_header)
           m_JA.pre_process_raster = atoi(attr->value);
     }
 
+    if (((attr = ppdFindAttr(m_ppd, "HPSPDClass", NULL)) == NULL) ||
+         (attr && attr->value == NULL)) 
+    {
+        m_JA.HPSPDClass = 0;
+    }
+    else
+    {
+        m_JA.HPSPDClass = atoi(attr->value);
+    }
+    
 
 // Get the encapsulation technology from ppd
 
@@ -436,8 +471,10 @@ DRIVER_ERROR HPCupsFilter::startPage (cups_page_header2_t *cups_header)
     }
 
     string strPrinterURI="" , strPrinterName= "";
-    if (getenv("DEVICE_URI"))
-        m_DBusComm.initDBusComm(DBUS_PATH,DBUS_INTERFACE, getenv("DEVICE_URI"), m_JA.printer_name);
+    if(!IsChromeOs()){
+      if (getenv("DEVICE_URI"))
+          m_DBusComm.initDBusComm(DBUS_PATH,DBUS_INTERFACE, getenv("DEVICE_URI"), m_JA.printer_name);
+    }
 
     ptr = strstr(m_argv[5], "job-uuid");
     if (ptr) {
@@ -498,6 +535,16 @@ int HPCupsFilter::StartPrintJob(int  argc, char *argv[])
     memset(m_JA.job_start_time,0,sizeof(m_JA.job_start_time));
     snprintf(m_JA.job_start_time, sizeof(m_JA.job_start_time),"Mon Dec  9 17:48:58:586 2013" );
 #endif
+   
+    if((strstr(argv[5],"Duplex=DuplexTumble")) || (strstr(argv[5],"Duplex=DuplexNoTumble")) || (strstr(argv[5],"sides=two-sided-short-edge")) || (strstr(argv[5],"sides=two-sided-long-edge")) )
+
+    {
+        m_JA.args_duplex_mode = 2; // short edge duplex always
+    }
+    else
+    {
+        m_JA.args_duplex_mode = 0; // simplex
+    }
 
     m_iLogLevel = getHPLogLevel();
     m_JA.job_id = atoi(argv[1]);
@@ -613,10 +660,26 @@ int HPCupsFilter::processRasterData(cups_raster_t *cups_raster)
 
 
     sprintf(hpPreProcessedRasterFile, "%s/hp_%s_cups_SwapedPagesXXXXXX",CUPS_TMP_DIR, m_JA.user_name);
-
-
+    #ifndef DISABLE_IMAGEPROCESSOR 
+	    image_processor_t* imageProcessor=NULL;
+	    IMAGE_PROCESSOR_ERROR result;
+	    //added if condition to check if pinter language is "ljzjstream"
+	    //If so, then bypass imageprocessing functions while running HPCUPS filter.
+	    
+	    if(strncmp(m_JA.printer_platform, "ljzjstream",10) == 0){
+		imageProcessor = imageProcessorCreate();
+	    }
+    #endif
     while (cupsRasterReadHeader2(cups_raster, &cups_header))
     {
+       #ifndef DISABLE_IMAGEPROCESSOR 
+		   if(strncmp(m_JA.printer_platform, "ljzjstream",10) == 0){
+		    result = imageProcessorStartPage(imageProcessor, &cups_header);
+		    if (result != IPE_SUCCESS){
+		        dbglog("DEBUG: imageProcessorStartPage failed result = %d\n", result);
+		    }
+		    }
+       #endif
         current_page_number++;
 
         if (current_page_number == 1) {
@@ -714,7 +777,15 @@ int HPCupsFilter::processRasterData(cups_raster_t *cups_raster)
             cupsRasterReadPixels (cups_raster, m_pPrinterBuffer, cups_header.cupsBytesPerLine);
             color_raster = rgbRaster;
             black_raster = kRaster;
-
+            #ifndef DISABLE_IMAGEPROCESSOR 
+				if(strncmp(m_JA.printer_platform, "ljzjstream",10) == 0)
+				{
+						result = imageProcessorProcessLine(imageProcessor, m_pPrinterBuffer, cups_header.cupsBytesPerLine);
+						if (result != IPE_SUCCESS){
+						    dbglog("DEBUG: imageProcessorProcessLine failed result = %d\n", result);
+						}
+				}
+            #endif
             if ((y == 0) && !is_ljmono) {
                 //For ljmono, make sure that first line is not a blankRaster line.Otherwise printer
                 //may not skip blank lines before actual data
@@ -743,7 +814,15 @@ int HPCupsFilter::processRasterData(cups_raster_t *cups_raster)
                 WriteBMPRaster (kfp, black_raster, cups_header.cupsWidth/8, BLACK_RASTER);
             }
         }  // for() loop end
-
+		#ifndef DISABLE_IMAGEPROCESSOR 
+			if(strncmp(m_JA.printer_platform, "ljzjstream",10) == 0)
+			{
+				result = imageProcessorEndPage(imageProcessor);
+				if (result != IPE_SUCCESS){
+				        dbglog("DEBUG: imageProcessorEndPage failed result = %d\n", result);
+				}
+			}
+		#endif
         m_Job.NewPage();
         if (err != NO_ERROR) {
             break;
@@ -758,6 +837,13 @@ int HPCupsFilter::processRasterData(cups_raster_t *cups_raster)
         rgbRaster = NULL;
     }
 
+   #ifndef DISABLE_IMAGEPROCESSOR
+	   if(strncmp(m_JA.printer_platform, "ljzjstream",10) == 0)
+	   {
+		imageProcessorDestroy(imageProcessor);
+	   }
+   #endif
+
     unlink(hpPreProcessedRasterFile);
     return ret_status;
 }
